package dialogs;

import java.awt.Color;
import java.awt.FlowLayout;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;

import javax.swing.JComponent;
import javax.swing.JFileChooser;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JPanel;
import javax.swing.JButton;
import javax.swing.JTextField;

import main.*;

public class GameMenu extends JPanel{
	private GameMain _main;
	public Menu menu;
	public JButton nextgame;
	public JButton roster;
	public JButton standings;
	public JButton standings2;
	public JButton trades;
	public JButton stats;
	public JButton freeagents;
	public JButton contracts;
	private static Color orange = new Color(240,120,0);
	private static Color darkgreen = new Color(0,80,0);
	private static Color white = new Color(255,255,255);
	private HelpButton helpbutton;
	private static Color red = new Color(255,0,0);
	private static Color blue = new Color(0,0,200);
	private static Color yellow = new Color(255,250,200);
	public GameMenu(GameMain main) {
		super();
		
		_main=main;
		menu = new Menu(_main);
		helpbutton = main.help;
		_main.setJMenuBar(menu);
		setLayout(new GridBagLayout());
		
		GridBagConstraints c = new GridBagConstraints();		
		c.insets=new Insets(5,5,5,5);
		
		int i=0;
		
		roster = new JButton("Roster"); 
		style(roster);
		roster.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				_main.mainpanel.removeAll();
				_main.mainpanel.add(new GameRoster(_main));
				helpbutton.updateState(HelpButton.ROSTER);
				_main.repaint();
			}
		});
		c.gridx = 0; c.gridy = i; this.add(roster,c);
		i++;
		
		freeagents= new JButton("Free Agents"); 
		style(freeagents);
		freeagents.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				_main.mainpanel.removeAll();
				helpbutton.updateState(HelpButton.FA);
				_main.mainpanel.add(new GameFreeAgents(_main,0, QuickSort.NAME));
				_main.repaint();
			}
		});
		c.gridx = 0; c.gridy = i; this.add(freeagents,c);
		i++;
		contracts = new JButton("Contracts"); 
		style(contracts);
		contracts.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				_main.mainpanel.removeAll();
				helpbutton.updateState(HelpButton.CONTRACTS);
				_main.mainpanel.add(new GameContracts(_main));
				_main.repaint();
			}
		});
		c.gridx = 0; c.gridy = i; this.add(contracts,c);
		i++;
		trades = new JButton("Trades"); 
		style(trades);
		trades.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				_main.mainpanel.removeAll();
				helpbutton.updateState(HelpButton.TRADES);
				_main.mainpanel.add(new GameTrade(_main, 0));
				_main.repaint();
			}
		});
		c.gridx = 0; c.gridy = i; this.add(trades,c);
		i++;
		standings = new JButton("Standings"); 
		style(standings);
		standings.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				_main.mainpanel.removeAll();
				_main.mainpanel.add(new GameStandings(_main));
				_main.repaint();
			}
		});
		c.gridx = 0; c.gridy = i; this.add(standings,c);
		i++;
		standings2 = new JButton("Stats"); 
		style(standings2);
		standings2.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				_main.mainpanel.removeAll();
				_main.mainpanel.add(new GameLeaders(_main,0));
				_main.repaint();
			}
		});
		c.gridx = 0; c.gridy = i; this.add(standings2,c);
		i++;
		
		stats = new JButton("Player-Stats");
		style(stats);
		stats.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				_main.mainpanel.removeAll();
				_main.mainpanel.add(new GamePlayerStats(_main, _main.team));
				_main.repaint();
			}
		});
		c.gridx = 0; c.gridy = i; this.add(stats,c);
		i++;
		
		nextgame = new JButton("Next Game");
		style(nextgame);
		nextgame.addActionListener(nextGameListener);
		c.gridx = 0; c.gridy = i; this.add(nextgame,c);

		update();
		
	}
	
	public void update() {
		if (_main.season_phase == Game.SEASON_REGULAR ){
			nextgame.setText("Next Game");
			setEnabledAll(true);

		}
		else if( _main.season_phase == Game.SEASON_PLAYOFFS || _main.season_phase == Game.SEASON_FINALS) {
			nextgame.setText("Next Game");
			setEnabledAll(true);
			freeagents.setEnabled(false);
			trades.setEnabled(false);

		}
		else if (_main.season_phase == Game.SEASON_AFTER_RS) {
			nextgame.setText("Start Playoffs");
			
			setEnabledAll(true);
			freeagents.setEnabled(false);
			trades.setEnabled(false);
		}
		else if (_main.season_phase == Game.SEASON_AFTER_PO) {
			nextgame.setText("Finish Season");
			setEnabledAll(true);
			freeagents.setEnabled(false);
			trades.setEnabled(false);
		}
		else if (_main.season_phase == Game.SEASON_DRAFT) {
			nextgame.setText("Start Draft");
			setEnabledAll(true);
			freeagents.setEnabled(false);
			helpbutton.updateState(HelpButton.DRAFT);
		}
		else if (_main.season_phase == Game.SEASON_DURING_DRAFT) {
			nextgame.setText("..Draft..");
			setEnabledAll(false);
			helpbutton.updateState(HelpButton.DRAFT);
			
		}
		else if (_main.season_phase == Game.SEASON_OFFSEASON) {
			nextgame.setText("Start Season");
			setEnabledAll(true);
			
		}
		
		
	}
	public void setEnabledAll(boolean v) {
		nextgame.setEnabled(v);
		standings.setEnabled(v);
		stats.setEnabled(v);
		roster.setEnabled(v);
		freeagents.setEnabled(v);
		contracts.setEnabled(v);
		menu.save.setEnabled(v);
		standings2.setEnabled(v);
		trades.setEnabled(v);
	}
	public void style(JComponent j) {
		//j.setBackground(darkgreen);
		j.setForeground(darkgreen);
	}
	private class Menu extends JMenuBar{
		JMenu _file;
		JMenu _misc;
		GameMain _main;
		JMenuItem save;
		JMenuItem hof;
		
		public Menu(GameMain main) {
			super();
			_main = main;
			_file = new JMenu("File");
			_misc = new JMenu("Misc");
			
			
			save = new JMenuItem("Save", 'S');
			save.addActionListener(savelistener);
			_file.add(save);
			JMenuItem item = new JMenuItem("Load", 'L');
			item.addActionListener(loadlistener);
			_file.add(item);
			hof= new JMenuItem("Hall of Fame", 'H');
			hof.addActionListener(hsListener);
			_misc.add(hof);

			
			this.add(_file);
			this.add(_misc);
		}
		
		
		ActionListener savelistener = new ActionListener() {
			public void actionPerformed(ActionEvent event) {
				JFileChooser chooser = new JFileChooser("data/savegames/");
				
				int returnVal = chooser.showSaveDialog(null);
				if (returnVal == JFileChooser.APPROVE_OPTION) {
					
					
					File file = chooser.getSelectedFile();
					if (file.getName().endsWith(".pb08")){
						
						
					}
					else {
						try {
							file = new File(file.getCanonicalPath()+".pb08");
						} catch (Exception ex) {}
						
						
					}
					boolean saved = Game.save(file, _main);
					
				}
			}
		};
		ActionListener loadlistener = new ActionListener() {
			public void actionPerformed(ActionEvent event) {
				JFileChooser chooser = new JFileChooser("data/savegames/");
				
				int returnVal = chooser.showOpenDialog(null);
				if (returnVal == JFileChooser.APPROVE_OPTION) {
					File file = chooser.getSelectedFile();
					Game game = Game.load(file);
					_main.loadGame(game);
					_main.nextGame();
					_main.repaint();
					
				}
			}
		};
		ActionListener hsListener = new ActionListener() {
			public void actionPerformed(ActionEvent event) {
				HighScore.displayHighScore();
			}
		};
	}
	ActionListener nextGameListener =  new ActionListener() {
		public void actionPerformed(ActionEvent e) {
			_main.mainpanel.removeAll();
			helpbutton.updateState(HelpButton.BEFOREGAME);
			if (_main.season_phase == Game.SEASON_REGULAR) _main.mainpanel.add(new GameBeforeMatch(_main));
			else if (_main.season_phase == Game.SEASON_AFTER_RS) _main.mainpanel.add(new GameAfterRS(_main));
			else if (_main.season_phase == Game.SEASON_PLAYOFFS) _main.mainpanel.add(new GameBeforeMatch(_main));
			else if (_main.season_phase == Game.SEASON_FINALS) _main.mainpanel.add(new GameBeforeMatch(_main));
			else if (_main.season_phase == Game.SEASON_AFTER_PO) _main.mainpanel.add(new GameAfterPO(_main));
			else if (_main.season_phase == Game.SEASON_DRAFT) _main.mainpanel.add(new GameDraft(_main));
			else if (_main.season_phase == Game.SEASON_OFFSEASON){
				League.startSeason(_main);
				
				_main.mainpanel.add(new GameRoster(_main));
			}
			
			
			_main.repaint();
		}
	};
	
}
