package main;

import java.awt.List;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Arrays;
import java.util.Collections;

import dialogs.*;
public class Team implements Comparable {
  public int compareTo(Object o2) {
	   	int s1 = this.games_won;
	   	int s2 = ((Team)o2).games_won;
	   	int n1 = this.games_lost;
	   	int n2 = ((Team)o2).games_lost;
	   	
	    return (s2-s1)*10 + (n1-n2) ;
	  }
  	public int deadsalary=0;
  	public int credits;
  	public int score;
  	public int[] draftpicks = new int[0];
  	public DraftPick[] futuredraftpicks = new DraftPick[0];
	public String name;
	public Player[] players;
	public String filename;
	public String[] playerfiles;
	public int games_won =0;
	public int games_lost=0;
	public Team() {
		players=new Player[15];
		
		for (int i=0; i<15;i++) {
			players[i] = new Player();
		}
		playerfiles = new String[15];
		for (int i=0; i<15;i++) {
			playerfiles[i] = "";
		}
		filename = "";
		name = "";
	}
	
	public void resetStats() {
		for (int i =0;i<15;i++) {
			players[i].resetStats();
		}
		games_won = 0;
		games_lost = 0;
		
	}
	
	public static Team fromFile(File f) {
		Team team = new Team();
		
		team.filename = f.getName();
		if (team.filename.endsWith(".pb08")) team.filename = team.filename.substring(0, team.filename.length()-5);
		
		                                 
		try {
			FileInputStream fis =  new FileInputStream(f);
			char c = (char)fis.read();

			while (c != '|'){
				team.name +=c;
				c=(char)fis.read();
			}
			c=(char)fis.read();
			for (int i=0;i<15;i++) {
				String playerfile=new String("");
				
				while (c != '|'){
					playerfile +=c;
					c=(char)fis.read();
				}
				c=(char)fis.read();
				
				team.playerfiles[i] = playerfile;
	
				File pfile = new File("data/players/"+playerfile+".pb08");
				
				if (pfile.exists()) {
					
					team.players[i] = Player.readPlayer(pfile);
				}
				else team.players[i] = new Player();
			}
			
		} catch (IOException ex) {}
		
		
		
		return team;
	}
	public void save() {
		File f = new File("data/teams/"+this.filename+".pb08");
		if (f.exists()) {
			
		}
		else {
			try {
				f.createNewFile();
			} catch (IOException ex){System.err.println(ex.getMessage());}
		}
		try {
			FileOutputStream fos = new FileOutputStream(f);
			char[] b = name.toCharArray();
			for (int j=0;j<b.length;j++){
				fos.write(b[j]);	
			}
			fos.write('|');
			for (int i =0;i<15;i++) {
				b = playerfiles[i].toCharArray();
				for (int j=0;j<b.length;j++){
					fos.write(b[j]);	
				}
				fos.write('|');
				
			}
			fos.close();
		} catch (IOException ex) {}
		
	}
	public double avg_rating() {
		int sum = 0;
		for (int i =0;i<10;i++) {
			int skills = players[i].skill_defense + players[i].skill_passing+players[i].skill_rebounds+players[i].skill_scoring;
			if (i<5) skills=skills*2;
			sum += skills;
		}
		return  ((int)sum / (6))/10.0;
	}
	public void findRosterSpot(Player candidate, League league) {
		boolean posfound=false;
		for (int i=14;i>=0; i--) {
			if (!players[i].real()) {
				players[i] = candidate;
				posfound =true;
				break;
			}
		}
		if (!posfound) {
			for (int i=14;i>=0; i--) {
				if (players[i].overallValue()+10 < candidate.overallValue()
						&& (i>9|| (i+1 - candidate.position==0) || i-4 - candidate.position==0)) {
					Player tmp = players[i];
					players[i] = candidate;
					league.addFA(tmp);
					break;
				}
			}
		}
	}
	
	public int freeSpots() {
		int v=15;
		for (int i=0;i<15;i++) {
			if (players[i].real()) v--;
		}
		return v;
	}
	public String ageEffectText() {
		String str = "The ratings of your players changed: \n";
		for (int i=0;i<15;i++) {
			if (players[i].real()) str += players[i].ageEffectText();
		}
		return str;
	}
	
	public void optimizeRoster() {
		Player[] tmpplayers = new Player[15-freeSpots()];
		int i=0;
		int j=0;
		while (j<tmpplayers.length) {
			if (players[i].real()) {
				tmpplayers[j] = players[i];
				j++;
			}
			i++;
		}
		Collections.sort(Arrays.asList(tmpplayers));

		Player[] blankteam = new Player[15];
		for (int i1=0;i1<15;i1++) {

			blankteam[i1] = new Player();
		}

		for (int i1=0;i1<tmpplayers.length;i1++) {
			Player p = tmpplayers[i1];
			if (!blankteam[p.position-1].real()) {
				blankteam[p.position-1] = p;
			}
			else if (!blankteam[p.position+4].real()) {
				blankteam[p.position+4] = p;
			}
			else {
				for (int i2=tmpplayers.length-1;i2>=0;i2--) {

					if (!blankteam[i2].real()) {
						blankteam[i2] =p;
						break;
					}
				}
			}
		}
		players = blankteam;
		
	}
}
